Test Failures
setTimeout | 120000 |
open | ../core/TestRunner.html?test=../tests/ErrorCheckingTestSuite.html |
waitForEval | window.htmlTestRunner.testCaseLoaded | true
Run First Test Case
click | runSeleniumTest |
waitForText | testRuns | 1
verifyAttribute | failure1@class | regex:status_failed
verifyAttribute | failure2@class | regex:status_failed
verifyAttribute | failure3@class | regex:status_failed
verifyAttribute | failure4@class | regex:status_failed
verifyAttribute | failure5@class | regex:status_failed
verifyAttribute | failure6@class | regex:status_failed